import Qt 4.7
import QtWebKit 1.0

import "imports/XAComponents"
import "Inspector"

Item {
    id: maincomponent

    property string windowTitle : qtInputTitle
    property string windowGotFocus : qtWindowGotFocus
    property string platformID: qtPlatformID

    property string itemUID: qtItemUID

    property alias itemComment: commentInput.text

    anchors.fill: parent

    focus: true
    //Keys.enabled: true

    onWindowTitleChanged: {
//        console.debug("<< onWindowTitleChanged")
        maincomponent.focus = true
        Keys.enabled = true
    }

    function setComment(comment) {
        console.debug("QML++++ setComment")
        console.debug(comment);

        commentInput.text = comment;
    }

    function activateInputFocus() {
        console.debug("QML++++ activateInputFocus")

        commentInput.focus = true;
    }

    function closeWindow() {
//        console.debug("<< closeWindow()")

        QtHandler.CloseButtonClicked();
    }

    Rectangle {
        id: windowRect
        opacity: 0.9
        //color: "#eeffffff"
        color: "#eefdfdcf"

        radius: 6
        smooth: true
        anchors.fill: parent
        anchors.rightMargin: (maincomponent.platformID == "WIN" ? 1 : 0)
        anchors.bottomMargin: (maincomponent.platformID == "WIN" ? 1 : 0)

        //clip: true

        //
        // window title bar
        //

        XAWindowTitleBarNotepad {
            id: xaWindowTitleBar
            windowTitle: maincomponent.windowTitle
            windowGotFocus: maincomponent.windowGotFocus
            windowDrawBorder: (maincomponent.platformID == "WIN")
            platformID: maincomponent.platformID
        }

        //
        // comment editor
        //

        AIActionDetailsCommentEditor {
            id: commentInput
            anchors.fill: parent
            anchors.leftMargin: 4
            anchors.rightMargin: 4
            anchors.topMargin: 20
            anchors.bottomMargin: 20

            onUpdated: {
                console.debug("Comment in Comment Inspector changed to: ")
                console.debug(newComment)

                QtHandler.dataChanged(maincomponent.itemUID, "comment", newComment)
                QtHandler.dataChanged(maincomponent.itemUID, "delegatedto", "1")
            }

        }
    }

    //
    // bottom bar
    //

    Rectangle {
        id: bottombarRect
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.bottom
        anchors.topMargin: -19
        height: 19

        color: "transparent"

        Rectangle {
            id: bottomBarDivisionLine
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            height: 1

            opacity: 0.2
            color: "gray"
        }

        MouseArea {
            id: bottombarDragArea
            anchors.fill: parent
            anchors.rightMargin: 15
            clip: false
            visible: true
            anchors.right: parent.right
            anchors.left: parent.left
            anchors.top: parent.top
            acceptedButtons: Qt.LeftButton

            onPressed: {
                QtHandler.startMoveTrigger(mouseX, mouseY)
            }
            onPositionChanged: {
                QtHandler.moveTrigger(mouseX, mouseY);
            }
        }

        Image {
            id: bottombarResizeImage
            //anchors.top: parent.top
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            width: 15
            height: 15
            source: "imports/XAComponents/pics/PreviewCornerResizeHandle15px.png"

            MouseArea {
                id: bottombarResizeArea
                anchors.fill: parent
                clip: false
                visible: true
                acceptedButtons: Qt.LeftButton

                onPressed: {
                    QtHandler.startResizeTrigger(mouseX, mouseY)
                }
                onPositionChanged: {
                    QtHandler.resizeTrigger(mouseX, mouseY);
                }
            }
        }


    }
}
